import QtQuick 2.0
import QtQuick.Layouts 1.2

import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.components 2.0 as PlasmaComponents

// Additional imports.
import QtQuick.Controls 1.4
import QtQuick.Controls.Styles 1.4

import SddmComponents 2.0

SessionManagementScreen {

    //default
    property string passType
    property string currPass

    property string notificationMessage

    property bool firstCheck: true

    function responseChangePwd() {
        var password = changePasswordBox.text

        if (firstCheck) {
            if (password != currPass){
                notificationMessage = textConstants.wrongPassword
            }
            firstCheck = false
        }

        pamconverhelper.responsePamConnection(password)
    }

    PlasmaComponents.Label {
        anchors.topMargin: 20
        id: messageInfo
        text: i18n(notificationMessage)
        Layout.fillWidth: true

        wrapMode: Text.WordWrap

        Connections {
            target: pamconverhelper

            onChangeCurrentPamMessage: function(pamMessage) {
                messageInfo.text = i18n(pamMessage)
            }
        }
    }


    PlasmaComponents.TextField {

        id: loginInfoBox
        focus: false
        enabled: false
        visible: !showSingleUser
        opacity: 0.5

        Layout.fillWidth: true
        text: currentUser

        style: TextFieldStyle {
            textColor: "#F4F4F4"
            selectedTextColor: "#FFFFFF"
            selectionColor: "#CD3D3C"
            placeholderTextColor: "#F4F4F4"
            background: Rectangle {
                color: "#2B2B2B"
                radius: 2
                                                //hovered     //normal
                border.color: control.hovered ? "#CD3D3C" : "#CD3D3C"
                border.width: 1
                implicitHeight: 30
            }
        }

        font.family: config.font
        font.pointSize: config.fontSize
        placeholderText: i18nd("plasma_lookandfeel_org.kde.lookandfeel", "Username")

        echoMode: TextInput.Normal

    }


    PlasmaComponents.TextField {

        id: changePasswordBox
        focus: true

        Layout.fillWidth: true

        style: TextFieldStyle {
            textColor: "#F4F4F4"
            selectedTextColor: "#FFFFFF"
            selectionColor: "#CD3D3C"
            placeholderTextColor: "#F4F4F4"
            background: Rectangle {
                color: "#2B2B2B"
                radius: 2
                                                //hovered     //normal
                border.color: control.hovered ? "#CD3D3C" : "#CD3D3C"
                border.width: 1
                implicitHeight: 30
            }
        }

        font.family: config.font
        font.pointSize: config.fontSize
        placeholderText: i18nd("plasma_lookandfeel_org.kde.lookandfeel", passType)

        echoMode: TextInput.Password
        revealPasswordButtonShown: true

        onAccepted: responseChangePwd()

        Keys.onEscapePressed: {
            mainStack.currentItem.forceActiveFocus();
        }

        //if empty and left or right is pressed change selection in user switch
        //this cannot be in keys.onLeftPressed as then it doesn't reach the password box
        Keys.onPressed: {
            if (event.key == Qt.Key_Left && !text) {
                userList.decrementCurrentIndex();
                event.accepted = true
            }
            if (event.key == Qt.Key_Right && !text) {
                userList.incrementCurrentIndex();
                event.accepted = true
            }
        }

        Connections {
            target: pamconverhelper

            onChangeCurrentPamRequest: function(pamRequest) {
                changePasswordBox.placeholderText = i18nd("plasma_lookandfeel_org.kde.lookandfeel", pamRequest)
                changePasswordBox.text = ""
                changePasswordBox.forceActiveFocus()
            }
        }
    }

    PlasmaComponents.Button {
        id: loginButton
        Layout.fillWidth: true

        style: ButtonStyle {
            background: Rectangle {
                border.width: 1
                                                //hovered     //normal
                border.color: control.hovered ? "#CD3D3C" : "#CD3D3C"
                radius: 2
                gradient: Gradient {                                      //hovered   //normal
                    GradientStop { position: 0 ; color: control.pressed ? "#CD3D3C" : "#CD3D3C" }
                    GradientStop { position: 1 ; color: control.pressed ? "#CD3D3C" : "#CD3D3C" }
                }
                implicitHeight: 30
            }
            label: Component {
                id: labelLogin
                Row {
                    anchors.left: parent.left
                    anchors.leftMargin: (parent.width - (textlogin.width + image.width))/2
                    anchors.top: parent.top
                    anchors.topMargin: 0
                    spacing: 0
                    Image {
                        id: image
                        source: control.iconSource
                    }
                    Label {
                        id: textlogin
                        height: parent.height
                        width: parent.width
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "#FFFFFF"
                        text: control.text
                        font.family: config.font
                        font.pointSize: config.fontSize
                        font.underline: loginButton.activeFocus
                    }
                }
            }
        }
        text: i18nd("plasma_lookandfeel_org.kde.lookandfeel", textConstants.continueText)
        onClicked: responseChangePwd();
    }

    anchors.fill: root
    actionItems: [
        ActionButton {
            iconSource: "go-previous"
            text: i18nd("plasma_lookandfeel_org.kde.lookandfeel","Back")
            onClicked: {
                mainStack.pop()
                pamconverhelper.cancelConnection()
            }
        }
    ]
}
